summaryrefslogtreecommitdiffstats
path: root/lasso/lasso.h
diff options
context:
space:
mode:
authorFrederic Peters <fpeters@entrouvert.com>2004-10-27 09:49:13 +0000
committerFrederic Peters <fpeters@entrouvert.com>2004-10-27 09:49:13 +0000
commitf13772d62deb599c1c475f5b842ac76bdefc7e2f (patch)
tree3b217e851e54b477ecbf4df2cb6ded611574b1aa /lasso/lasso.h
parentc411dbc31f0938f513c4fb4ccc3b12a7b4ce6617 (diff)
downloadlasso-f13772d62deb599c1c475f5b842ac76bdefc7e2f.tar.gz
lasso-f13772d62deb599c1c475f5b842ac76bdefc7e2f.tar.xz
lasso-f13772d62deb599c1c475f5b842ac76bdefc7e2f.zip
Done with the move to structures and the removal of protocols/ (lasso branched
on October 2nd; occasional merges since then). - Compatible with current souk test suites. - Missing memory management for everything in xml/ - Missing xmlsec support for SOAP messages.
Diffstat (limited to 'lasso/lasso.h')
-rw-r--r--lasso/lasso.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/lasso/lasso.h b/lasso/lasso.h
index 85cbfa6e..10284f82 100644
--- a/lasso/lasso.h
+++ b/lasso/lasso.h
@@ -48,14 +48,14 @@ LASSO_EXPORT int lasso_shutdown(void);
/**
* lassoCheckVersionMode:
* @lassoCheckVersionExact: the version should match exactly.
* @lassoCheckVersionABICompatible: the version should be ABI compatible.
*
* The lasso library version mode.
*/
typedef enum {
- lassoCheckVersionExact = 0,
- lassoCheckVersionABICompatible
+ LASSO_CHECK_VERSION_EXACT = 0,
+ LASSO_CHECK_VERSIONABI_COMPATIBLE
} lassoCheckVersionMode;
/**
@@ -67,7 +67,7 @@ typedef enum {
*/
#define lasso_check_version_exact() \
lasso_check_version_ext(LASSO_VERSION_MAJOR, LASSO_VERSION_MINOR, \
- LASSO_VERSION_SUBMINOR, lassoCheckVersionExact)
+ LASSO_VERSION_SUBMINOR, LASSO_CHECK_VERSION_EXACT)
/**
* lasso_check_version:
@@ -79,7 +79,7 @@ typedef enum {
#define lasso_check_version() \
lasso_check_version_ext(LASSO_VERSION_MAJOR, LASSO_VERSION_MINOR, \
LASSO_VERSION_SUBMINOR, \
- lassoCheckVersionABICompatible)
+ LASSO_CHECK_VERSIONABI_COMPATIBLE)
LASSO_EXPORT int lasso_check_version_ext(int major,
int minor,
@@ -48,14 +48,14 @@ LASSO_EXPORT int lasso_shutdown(void);
/**
* lassoCheckVersionMode:
- * @lassoCheckVersionExact: the version should match exactly.
- * @lassoCheckVersionABICompatible: the version should be ABI compatible.
+ * @LASSO_CHECK_VERSION_EXACT: the version should match exactly.
+ * @LASSO_CHECK_VERSIONABI_COMPATIBLE: the version should be ABI compatible.
*
* The lasso library version mode.